@@ -156,7 +156,7 @@ static void set_metadata(GSTLALAudioUnderSample *element, GstBuffer *buf, guint6
 	GST_BUFFER_OFFSET_END(buf) = element->next_out_offset;
 	GST_BUFFER_TIMESTAMP(buf) = element->t0 + gst_util_uint64_scale_int_round(GST_BUFFER_OFFSET(buf) - element->offset0, GST_SECOND, element->rate_out);
 	GST_BUFFER_DURATION(buf) = element->t0 + gst_util_uint64_scale_int_round(GST_BUFFER_OFFSET_END(buf) - element->offset0, GST_SECOND, element->rate_out) - GST_BUFFER_TIMESTAMP(buf);
-	if(element->need_discont) {
+	if(G_UNLIKELY(element->need_discont)) {
 		GST_BUFFER_FLAG_SET(buf, GST_BUFFER_FLAG_DISCONT);
 		element->need_discont = FALSE;
 	}
@@ -409,7 +409,7 @@ static gboolean transform_size(GstBaseTransform *trans, GstPadDirection directio
 	 * convert byte count to samples
 	 */
 
-	if(size % unit_size) {
+	if(G_UNLIKELY(size % unit_size)) {
 		GST_DEBUG_OBJECT(element, "buffer size %u is not a multiple of %u", size, unit_size);
 		return FALSE;
 	}
@@ -507,7 +507,7 @@ static GstFlowReturn transform(GstBaseTransform *trans, GstBuffer *inbuf, GstBuf
 	 * check for discontinuity
 	 */
 
-	if(GST_BUFFER_IS_DISCONT(inbuf) || GST_BUFFER_OFFSET(inbuf) != element->next_in_offset || !GST_CLOCK_TIME_IS_VALID(element->t0)) {
+	if(G_UNLIKELY(GST_BUFFER_IS_DISCONT(inbuf) || GST_BUFFER_OFFSET(inbuf) != element->next_in_offset || !GST_CLOCK_TIME_IS_VALID(element->t0))) {
 		element->t0 = GST_BUFFER_TIMESTAMP(inbuf);
 		element->offset0 = element->next_out_offset = gst_util_uint64_scale_ceil(GST_BUFFER_OFFSET(inbuf), element->rate_out, element->rate_in);
 		element->need_discont = TRUE;
