@@ -60,11 +60,13 @@ struct _GSTLALDrop {
 	gint rate;
 	gint unit_size;
 	guint drop_samples;
+	gboolean need_discont;
 };
 
 
 /**
  * GSTLALDropClass:
+ * @parent_class:  the parent class
  */
 
 
