@@ -22,10 +22,10 @@
 
 /**
  * SECTION:gstlal_matrixmixer
- * @short_description:  Compute linear combinations of time series.
+ * @short_description:  Compute linear combinations of time series channels.
  *
- * Generates one or more time series streams as linear combinations of one
- * or more input streams.  The mixer is controlled using a matrix whose
+ * Generates one or more time series channels as linear combinations of one
+ * or more input channels.  The mixer is controlled using a matrix whose
  * elements provide the mixing coefficients and whose size sets the number
  * of input and output channels.  The meaning of the coefficients is shown
  * in the following diagram.
@@ -43,6 +43,9 @@
  * buffer into an output buffer can be performed as a single matrix-matrix
  * multiplication, to allow optimized platform-specific implementations of
  * that operation to be employed.
+ *
+ * Reviewed:  d2dcd2d01c83be1f647a8713fef48e4249433218 2014-08-10 K.
+ * Cannon, J. Creighton, B. Sathyaprakash.
  */
 
 
@@ -220,8 +223,11 @@ static GstFlowReturn mix(GSTLALMatrixMixer *element, GstBuffer *inbuf, GstBuffer
 	 */
 
 	length = GST_BUFFER_OFFSET_END(inbuf) - GST_BUFFER_OFFSET(inbuf);
-	if(!length)
+	if(!length) {
+		g_assert_cmpuint(GST_BUFFER_SIZE(inbuf), ==, 0);
 		return GST_FLOW_OK;
+	}
+	g_assert_cmpuint(GST_BUFFER_SIZE(inbuf) % length, ==, 0);
 
 	/*
 	 * Wrap the input and output buffers in GSL matrix views, then mix
@@ -448,11 +454,8 @@ static GstFlowReturn transform(GstBaseTransform *trans, GstBuffer *inbuf, GstBuf
 		 */
 
 		GST_BUFFER_FLAG_SET(outbuf, GST_BUFFER_FLAG_GAP);
-		/* prepare_output_buffer() lied.  tell the truth */
-		/* FIXME:  put back when resampler can handle non-malloc()ed buffers */
-		/*GST_BUFFER_SIZE(outbuf) = 0;*/
-		/* FIXME:  this is needed if used in pipelines that don't
-		 * understand gaps at all */
+		/* memset() is needed for pipelines that don't understand
+		 * gaps at all */
 		memset(GST_BUFFER_DATA(outbuf), 0, GST_BUFFER_SIZE(outbuf));
 		result = GST_FLOW_OK;
 	}
@@ -468,28 +471,6 @@ done:
 }
 
 
-/*
- * prepare_output_buffer()
- */
-
-
-static GstFlowReturn prepare_output_buffer(GstBaseTransform *trans, GstBuffer *input, gint size, GstCaps *caps, GstBuffer **buf)
-{
-	GstFlowReturn result;
-
-	/* FIXME:  put back commented-out code when resampler can handle non-malloc()ed buffers */
-	result = gst_pad_alloc_buffer(GST_BASE_TRANSFORM_SRC_PAD(trans), GST_BUFFER_OFFSET(input), /*GST_BUFFER_FLAG_IS_SET(input, GST_BUFFER_FLAG_GAP) ? 0 :*/ size, caps, buf);
-	if(result != GST_FLOW_OK)
-		goto done;
-
-	/* lie to trick basetransform */
-	GST_BUFFER_SIZE(*buf) = size;
-
-done:
-	return result;
-}
-
-
 /*
  * ============================================================================
  *
@@ -719,7 +700,6 @@ static void gstlal_matrixmixer_class_init(GSTLALMatrixMixerClass *klass)
 	transform_class->set_caps = GST_DEBUG_FUNCPTR(set_caps);
 	transform_class->transform = GST_DEBUG_FUNCPTR(transform);
 	transform_class->transform_caps = GST_DEBUG_FUNCPTR(transform_caps);
-	transform_class->prepare_output_buffer = GST_DEBUG_FUNCPTR(prepare_output_buffer);
 
 	gst_element_class_add_pad_template(element_class, gst_static_pad_template_get(&src_factory));
 	gst_element_class_add_pad_template(element_class, gst_static_pad_template_get(&sink_factory));
