@@ -33,11 +33,11 @@ struct _GSTLALSegmentSrc {
     struct gstlal_segment_list	*seglist;
     gboolean			invert_output;
     gint			rate;
-    gint			width;
 };
 
 /**
  * GSTLALSegmentSrcClass:
+ * @parent_class:  the parent class
  */
 
 struct _GSTLALSegmentSrcClass {
