@@ -1,7 +1,7 @@
 /*
  * An interface to LALSimulation.  
  *
- * Copyright (C) 2008--2013  Kipp Cannon, Chad Hanna, Drew Keppel
+ * Copyright (C) 2008--2015  Kipp Cannon, Chad Hanna, Drew Keppel
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,8 +16,21 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Actions:
+ *
+ * - Sort out extra padding for injection series, simulation series, etc.
+ * - Make it possible to get all the injections from a frame file.
+ * - Why is a nano-second taken out at the beginning and added at the end?
+ * - Get lal to do a conditional taper at the start of the waveform and run it through
+ * a high-pass filter (need to check if this is really needed for BNS).
+ * - Should the conditional tapering be the responsibility of waveform
+ * developers or could it be done outside waveform generation?
+ * - consider patching lal to remove start/stop parameters from
+ * XML loading functions so that they just load everything
+ *
  */
-
+		   
 
 /*
  * ========================================================================
@@ -282,23 +295,10 @@ static int sim_inspiral_strain(REAL8TimeSeries **strain, SimInspiralTable *sim_i
 	 * collecting and returning a conditioned waveform suitable for
 	 * injection into an h(t) stream (after projection onto an antenna
 	 * respose).
-	 *
-	 * FIXME:  remove locks when we can be sure lal has been compiled
-	 * with pthread support
 	 */
 
-#ifndef LAL_PTHREAD_LOCK
-	gstlal_fftw_lock();
-#endif
-	if(XLALInspiralTDWaveformFromSimInspiral(&hplus, &hcross, sim_inspiral, deltaT) == XLAL_FAILURE) {
-#ifndef LAL_PTHREAD_LOCK
-		gstlal_fftw_unlock();
-#endif
+	if(XLALInspiralTDWaveformFromSimInspiral(&hplus, &hcross, sim_inspiral, deltaT) == XLAL_FAILURE)
 		XLAL_ERROR(XLAL_EFUNC);
-	}
-#ifndef LAL_PTHREAD_LOCK
-	gstlal_fftw_unlock();
-#endif
 
 	/* add the time of the injection at the geocentre to the
 	 * start times of the h+ and hx time series.  after this,
@@ -448,24 +448,12 @@ static int update_simulation_series(REAL8TimeSeries *h, GSTLALSimulation *elemen
 
 		/*
 		 * add detector strain to simulation_series
-		 *
-		 * FIXME:  remove the locking when we figure out how to
-		 * co-ordinate this with LAL
 		 */
 
-#ifndef LAL_PTHREAD_LOCK
-		gstlal_fftw_lock();
-#endif
 		if(XLALSimAddInjectionREAL8TimeSeries(element->simulation_series, inspiral_series, response)) {
-#ifndef LAL_PTHREAD_LOCK
-			gstlal_fftw_unlock();
-#endif
 			XLALDestroyREAL8TimeSeries(inspiral_series);
 			XLAL_ERROR(XLAL_EFUNC);
 		}
-#ifndef LAL_PTHREAD_LOCK
-		gstlal_fftw_unlock();
-#endif
 		XLALDestroyREAL8TimeSeries(inspiral_series);
 
 		/*
@@ -504,23 +492,10 @@ static int update_simulation_series(REAL8TimeSeries *h, GSTLALSimulation *elemen
 
 		/*
 		 * inject waveforms into that buffer
-		 *
-		 * FIXME: remove the locking when we figure out how to co-ordinate this with LAL
 		 */
 
-
-#ifndef LAL_PTHREAD_LOCK
-		gstlal_fftw_lock();
-#endif
-		if(XLALBurstInjectSignals(burst_series, element->injection_document->sim_burst_table_head, element->injection_document->time_slide_table_head, response)) {
-#ifndef LAL_PTHREAD_LOCK
-			gstlal_fftw_unlock();
-#endif
+		if(XLALBurstInjectSignals(burst_series, element->injection_document->sim_burst_table_head, element->injection_document->time_slide_table_head, response))
 			XLAL_ERROR(XLAL_EFUNC);
-		}
-#ifndef LAL_PTHREAD_LOCK
-		gstlal_fftw_unlock();
-#endif
 
 		/*
 		 * add waveforms buffer into simulation_series
@@ -675,21 +650,7 @@ static GstFlowReturn transform_ip(GstBaseTransform *trans, GstBuffer *buf)
 		/* FIXME:  hard-coded = BAD BAD BAD */
 		/*XLALINT8NSToGPS(&start, (INT8) 1 << 63);
 		XLALINT8NSToGPS(&end, ((INT8) 1 << 63) - 1);*/
-		/* FIXME remove locks when we can be sure LAL has been
-		 * compiled with pthread support.
-		 * load_injection_document() relies on testing the xlal
-		 * errno variable, which is only thread-safe when lal was
-		 * compiled with pthread locking turned on.  previously
-		 * there have also been thread safety problems in
-		 * libmetaio, but those have been fixed so it's just lal
-		 * that we're waiting on now. */
-#ifndef LAL_PTHREAD_LOCK
-		gstlal_fftw_lock();
-#endif
 		element->injection_document = load_injection_document(element->xml_location, start, end, 0.0);
-#ifndef LAL_PTHREAD_LOCK
-		gstlal_fftw_unlock();
-#endif
 		if(!element->injection_document) {
 			GST_ELEMENT_ERROR(element, RESOURCE, READ, (NULL), ("error loading \"%s\"", element->xml_location));
 			result = GST_FLOW_ERROR;
