@@ -121,6 +121,9 @@
 static const LIGOTimeGPS GPS_ZERO = {0, 0};
 
 
+#undef NORMDEBUGGING
+
+
 /*
  * ============================================================================
  *
@@ -297,6 +300,11 @@ static int make_workspace(GSTLALWhiten *element)
 		GST_ERROR_OBJECT(element, "failure creating Hann window: %s", XLALErrorString(XLALGetBaseErrno()));
 		goto error;
 	}
+	/* safety check in case numerical issues lead to the edge bins
+	 * being not exactly 0.  we require them to be exactly 0 in order
+	 * to affect the reset of the workspace between iterations */
+	g_assert_cmpfloat(hann_window->data->data[0], ==, 0);
+	g_assert_cmpfloat(hann_window->data->data[hann_window->data->length - 1], ==, 0);
 	if(!XLALResizeREAL8Sequence(hann_window->data, -zero_pad_length(element), fft_length(element))) {
 		GST_ERROR_OBJECT(element, "failure resizing Hann window: %s", XLALErrorString(XLALGetBaseErrno()));
 		goto error;
@@ -723,8 +731,10 @@ static GstFlowReturn whiten(GSTLALWhiten *element, GstBuffer *outbuf, guint *out
 
 		/*
 		 * Copy data from input queue into time-domain workspace.
-		 * No need to explicitly zero-pad the time series because
-		 * the window function will do it for us.
+		 * We explicitly clear the zero padding region of the
+		 * workspace just in case there's an inf or a nan in there
+		 * because multiplication by the window won't be enough to
+		 * reset those values.
 		 *
 		 * Note:  the workspace's epoch is set to the timestamp of
 		 * the workspace's first sample, not the first sample of
@@ -732,7 +742,9 @@ static GstFlowReturn whiten(GSTLALWhiten *element, GstBuffer *outbuf, guint *out
 		 * samples later).
 		 */
 
+		memset(&element->tdworkspace->data->data[0], 0, zero_pad * sizeof(*element->tdworkspace->data->data));
 		gst_audioadapter_copy_samples(element->input_queue, &element->tdworkspace->data->data[zero_pad], hann_length, &block_contains_gaps, &block_contains_nongaps);
+		memset(&element->tdworkspace->data->data[zero_pad + hann_length], 0, zero_pad * sizeof(*element->tdworkspace->data->data));
 		XLALINT8NSToGPS(&element->tdworkspace->epoch, element->t0);
 		XLALGPSAdd(&element->tdworkspace->epoch, (double) ((gint64) (element->next_offset_out + *outsamples - element->offset0) - (gint64) zero_pad) / element->sample_rate);
 
@@ -740,13 +752,19 @@ static GstFlowReturn whiten(GSTLALWhiten *element, GstBuffer *outbuf, guint *out
 		 * Apply (zero-padded) Hann window.
 		 */
 
-		/*{ unsigned kk; double s = 0; for(kk = 0; kk < element->tdworkspace->data->length; kk++) s += pow(element->tdworkspace->data->data[kk], 2); fprintf(stderr, "mean square before window = %.16g\n", s / kk); }*/
+#ifdef NORMDEBUGGING
+		{ unsigned kk; double s = 0; for(kk = 0; kk < element->tdworkspace->data->length; kk++) s += pow(element->tdworkspace->data->data[kk], 2); fprintf(stderr, "mean square before window = %.16g\n", s / kk); }
+#endif
 		if(!XLALUnitaryWindowREAL8Sequence(element->tdworkspace->data, element->hann_window)) {
 			GST_ERROR_OBJECT(element, "XLALUnitaryWindowREAL8Sequence() failed: %s", XLALErrorString(XLALGetBaseErrno()));
 			XLALClearErrno();
 			return GST_FLOW_ERROR;
 		}
-		/*{ unsigned kk; double s = 0; for(kk = 0; kk < element->tdworkspace->data->length; kk++) s += pow(element->tdworkspace->data->data[kk], 2); fprintf(stderr, "mean square after window = %.16g\n", s / kk); }*/
+#ifdef NORMDEBUGGING
+		{ unsigned kk; for(kk = 0; kk < zero_pad; kk++) if(element->tdworkspace->data->data[kk] != 0.) { fprintf(stderr, "\t<-- non-zero samples left of Hann window (index %d)\n", kk); break; } }
+		{ unsigned kk; for(kk = zero_pad + hann_length; kk < element->tdworkspace->data->length; kk++) if(element->tdworkspace->data->data[kk] != 0.) { fprintf(stderr, "\t<-- non-zero samples right of Hann window (index %d)\n", kk); break; } }
+		{ unsigned kk; double s = 0; for(kk = 0; kk < element->tdworkspace->data->length; kk++) s += pow(element->tdworkspace->data->data[kk], 2); fprintf(stderr, "mean square after window = %.16g\n", s / kk); }
+#endif
 
 		/*
 		 * The next steps can be skipped if all we have are zeros
@@ -762,7 +780,9 @@ static GstFlowReturn whiten(GSTLALWhiten *element, GstBuffer *outbuf, guint *out
 				XLALClearErrno();
 				return GST_FLOW_ERROR;
 			}
-			/*{ unsigned kk; double s = 0; for(kk = 0; kk < element->fdworkspace->data->length; kk++) s += pow(cabs(element->fdworkspace->data->data[kk]), 2); fprintf(stderr, "mean square after FFT = %.16g\n", s / kk); }*/
+#ifdef NORMDEBUGGING
+			{ unsigned kk; double s = 0; for(kk = 0; kk < element->fdworkspace->data->length; kk++) s += pow(cabs(element->fdworkspace->data->data[kk]), 2); fprintf(stderr, "mean square after FFT = %.16g\n", s / kk); }
+#endif
 
 			/*
 			 * Retrieve the PSD.
@@ -821,7 +841,9 @@ static GstFlowReturn whiten(GSTLALWhiten *element, GstBuffer *outbuf, guint *out
 				XLALClearErrno();
 				return GST_FLOW_ERROR;
 			}
-			/*{ unsigned kk; double s = 0; for(kk = 0; kk < element->fdworkspace->data->length; kk++) s += pow(cabs(element->fdworkspace->data->data[kk]), 2); fprintf(stderr, "mean square after whiten = %.16g\n", s / kk); }*/
+#ifdef NORMDEBUGGING
+			{ unsigned kk; double s = 0; for(kk = 0; kk < element->fdworkspace->data->length; kk++) s += pow(cabs(element->fdworkspace->data->data[kk]), 2); fprintf(stderr, "mean square after whiten = %.16g\n", s / kk); }
+#endif
 
 			/*
 			 * Transform to time domain.
@@ -832,7 +854,9 @@ static GstFlowReturn whiten(GSTLALWhiten *element, GstBuffer *outbuf, guint *out
 				XLALClearErrno();
 				return GST_FLOW_ERROR;
 			}
-			/*{ unsigned kk; double s = 0; for(kk = 0; kk < element->tdworkspace->data->length; kk++) s += pow(element->tdworkspace->data->data[kk], 2); fprintf(stderr, "mean square after IFFT = %.16g\n", s / kk); }*/
+#ifdef NORMDEBUGGING
+			{ unsigned kk; double s = 0; for(kk = 0; kk < element->tdworkspace->data->length; kk++) s += pow(element->tdworkspace->data->data[kk], 2); fprintf(stderr, "mean square after IFFT = %.16g\n", s / kk); }
+#endif
 
 			/* 
 			 * Normalize the time series.
@@ -856,7 +880,9 @@ static GstFlowReturn whiten(GSTLALWhiten *element, GstBuffer *outbuf, guint *out
 				element->tdworkspace->data->data[i] *= element->tdworkspace->deltaT * sqrt(element->hann_window->sumofsquares);
 			/* normalization constant has units of seconds */
 			XLALUnitMultiply(&element->tdworkspace->sampleUnits, &element->tdworkspace->sampleUnits, &lalSecondUnit);
-			/*{ unsigned kk; double s = 0; for(kk = 0; kk < element->tdworkspace->data->length; kk++) s += pow(element->tdworkspace->data->data[kk], 2); fprintf(stderr, "mean square after normalization = %.16g\n", s / kk); }*/
+#ifdef NORMDEBUGGING
+			{ unsigned kk; double s = 0; for(kk = 0; kk < element->tdworkspace->data->length; kk++) s += pow(element->tdworkspace->data->data[kk], 2); fprintf(stderr, "mean square after normalization = %.16g\n", s / kk); }
+#endif
 
 			/*
 			 * Verify the result is dimensionless.
@@ -881,6 +907,9 @@ static GstFlowReturn whiten(GSTLALWhiten *element, GstBuffer *outbuf, guint *out
 					element->output_history->data[i] += element->tdworkspace->data->data[i];
 			}
 			element->nonzero_output_history_length = element->output_history->length;
+#ifdef NORMDEBUGGING
+			{ unsigned kk; double s = 0; for(kk = 0; kk < hann_length / 2; kk++) s += pow(element->output_history->data[kk], 2); fprintf(stderr, "mean square of output = %.16g\n", s / kk); }
+#endif
 		} else
 			element->tdworkspace->sampleUnits = lalDimensionlessUnit;
 
